@@ -41,11 +41,14 @@ tiny_imagenet_dataset <- torch::dataset(
 
     rlang::inform("Downloding tiny imagenet dataset!")
 
-    download.file(self$url, raw_path)
+    p <- download_and_cache(self$url)
+    fs::file_copy(p, raw_path)
 
     rlang::inform("Download complete. Now unzipping.")
 
-    zip::unzip(raw_path, exdir = self$root_path)
+    if (rlang::check_installed("zip")) {
+      zip::unzip(raw_path, exdir = self$root_path)
+    }
 
     # organize validation images
     val_path <- fs::path_join(c(self$root_path, self$tar_name, "val"))
